@@ -1,9 +1,9 @@
 /*
- * $Id: dialog.c,v 1.288 2022/04/06 08:04:56 tom Exp $
+ * $Id: dialog.c,v 1.291 2024/01/01 10:10:37 tom Exp $
  *
  *  cdialog - Display simple dialog boxes from shell scripts
  *
- *  Copyright 2000-2021,2022	Thomas E. Dickey
+ *  Copyright 2000-2023,2024	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -1538,7 +1538,7 @@ Help(void)
     static const char *const tbl_1[] =
     {
 	"cdialog (ComeOn Dialog!) version %s",
-	"Copyright 2000-2021,2022 Thomas E. Dickey",
+	"Copyright 2000-2023,2024 Thomas E. Dickey",
 	"This is free software; see the source for copying conditions.  There is NO",
 	"warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.",
 	"",
@@ -1971,6 +1971,10 @@ main(int argc, char *argv[])
 		    argv[1]);
 	    Usage(temp);
 	}
+#ifdef HAVE_COLOR
+	dialog_state.use_colors = USE_COLORS;	/* use colors by default? */
+	dialog_state.use_shadow = USE_SHADOW;	/* shadow dialog boxes by default? */
+#endif
 	if (dlg_parse_rc() == -1) {	/* Read the configuration file */
 	    handle_leaks();
 	    dlg_exiterr("dialog: dlg_parse_rc");
@@ -1978,7 +1982,7 @@ main(int argc, char *argv[])
 	dlg_create_rc(argv[2]);
 	dlg_exit(DLG_EXIT_OK);
     }
-#endif
+#endif /* HAVE_RC_FILE */
     else {
 	/*
 	 * Handle combinations of common options including --print-text-only
